@@ -12,7 +12,7 @@ use Perinci::Sub::Util qw(gen_modified_sub);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-12-05'; # DATE
 our $DIST = 'File-FindUniq'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 sub _glob {
     require File::Find;
@@ -346,7 +346,8 @@ sub uniq_files {
     my $exclude_empty_files   = delete($args{exclude_empty_files}) // 0;
     my $min_size              = delete($args{min_size});
     my $max_size              = delete($args{max_size});
-    return [400, "Unknown argument(s): ".join(", ", sort keys %args)] if keys %args;
+    return [400, "Unknown argument(s): ".join(", ", sort keys %args)]
+        if grep {!/\A-/} keys %args;
 
     if ($detail) {
         $show_digest = 1;
@@ -687,7 +688,7 @@ File::FindUniq - Find unique or duplicate file {contents,names}
 
 =head1 VERSION
 
-This document describes version 0.001 of File::FindUniq (from Perl distribution File-FindUniq), released on 2024-12-05.
+This document describes version 0.002 of File::FindUniq (from Perl distribution File-FindUniq), released on 2024-12-05.
 
 =head1 SYNOPSIS
 
